<?xml version="1.0" encoding="UTF-8" ?>

<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:m='http://www.milowski.com/examples/mydoc'
   xmlns:i="http://www.milowski.com/examples/itemlist"
   xmlns:di="http://www.docbook.org/itemlist"
   xmlns:h="http://www.w3.org/1999/xhtml"
>

<!-- DO NOT EDIT THIS STYLESHEET.  It should run all by itself without modification. -->

<xsl:template match="/">
<html>
<head>
 <title>Infoset</title>
 <xsl:call-template name="style"/>
</head>
<body>
   <xsl:call-template name="dump-document"/>
   </body>
</html>
</xsl:template>

<xsl:template name="style">
 <style type="text/css">

div.item {
    padding: 3pt;
    border: 1pt solid gray;
    margin-bottom: 10pt;
}
p.property {
   margin-after: 5pt;
   padding-left: 15pt;
}

p.item-type {
   border-bottom: 1pt solid gray;
}

span.property-label {
  font-weight: bold;
}

p.property-label {
  font-weight: bold;
}

div.property {
   margin-after: 5pt;
   padding-left: 15pt;
}

div.item-list {
   padding: 5pt;
   padding-left: 15pt;
}

p.item-ref {
   border: 1pt solid gray;
   padding: 3pt;
   margin-right: 2pt;
}

a {
   text-decoration: none;
   color: black;
}

a:link,a:visited {
   color: black;
}

a:hover {
   color: red;
}

</style>
</xsl:template>

<xsl:template name="dump-document">
    <div class="item" id="root">
    <xsl:call-template name="item-type">
    <xsl:with-param name='type' select="'document'"/>
    </xsl:call-template>
    <xsl:call-template name="item-children"/>
   <div class="property">
      <p class="property-label">[document element]</p>
      <div class="item-list">
       <xsl:apply-templates select="*" mode="item-nodeset"/>
      </div>
   </div>
    </div>
    <xsl:apply-templates select="*"/>
</xsl:template>

<xsl:template match="*">
    <div class="item">
    <xsl:if test="self::*">
    <xsl:attribute name="id">element_<xsl:value-of select="name(.)"/>_<xsl:value-of select="position()"/></xsl:attribute>
    </xsl:if>
    <xsl:call-template name="item-type"/>
    <p class="property"><span class="property-label">[namespace name]</span><xsl:text> </xsl:text>
    <xsl:value-of select="namespace-uri(.)"/>
    </p>
    <p class="property"><span class="property-label">[local name]</span><xsl:text> </xsl:text>
    <xsl:value-of select="local-name(.)"/>
    </p>
    <p class="property"><span class="property-label">[prefix]</span><xsl:text> </xsl:text>
    <xsl:if test="contains(name(.),':')">
    <xsl:value-of select="substring-before(name(.),':')"/>
    </xsl:if>
    </p>
    <xsl:call-template name="item-children"/>
   <div class="property">
      <p class="property-label">[attributes]</p>
      <div class="item-list">
      <xsl:apply-templates select="@*" mode="item-nodeset"/>
      </div>
   </div>
   <div class="property">
      <p class="property-label">[in-scope namespaces]</p>
      <div class="item-list">
      <xsl:for-each select="namespace::*">
      <p class="item-ref"><xsl:value-of select="name(.)"/>=<xsl:value-of select="."/></p>
      </xsl:for-each>
      </div>
   </div>
    <p class="property"><span class="property-label">[parent]</span><xsl:text> </xsl:text>
    <xsl:choose>
    <xsl:when test="parent::*">
    <xsl:apply-templates select="parent::*" mode="item-nodeset"/>
    </xsl:when>
    <xsl:otherwise>
    <p class="item-ref"><a href="#root">(document)</a></p>
    </xsl:otherwise>
    </xsl:choose>
    </p>
    </div>
    <xsl:apply-templates/>
</xsl:template>

<xsl:template match="text()"/>


<xsl:template name="item-children">
<div class="property">
   <p class="property-label">[children]</p>
   <div class="item-list">
   <xsl:apply-templates mode="item-nodeset"/>
   </div>
</div>
</xsl:template>

<xsl:template match="*" mode="item-nodeset">
<p class="item-ref"><a href="#element_{name(.)}_{position()}">{<xsl:value-of select="namespace-uri(.)"/>}<xsl:value-of select="local-name(.)"/></a></p>
</xsl:template>

<xsl:template match="text()" mode="item-nodeset">
<p class="item-ref"><xsl:copy-of select="."/></p>
</xsl:template>

<xsl:template match="@*" mode="item-nodeset">
<p class="item-ref">{<xsl:value-of select="namespace-uri(.)"/>}<xsl:value-of select="local-name(.)"/>=<xsl:value-of select="."/></p>
</xsl:template>


<xsl:template name="item-type">
    <xsl:param name="type"/>
    <p class="item-type">
    <xsl:choose>
    <xsl:when test="$type"><xsl:value-of select="$type"/></xsl:when>
    <xsl:when test="self::*">element</xsl:when>
    <xsl:when test="self::text()">text</xsl:when>
    <xsl:when test="self::processing-instruction()">processing instruction</xsl:when>
    <xsl:when test="self::comment()">comment</xsl:when>
    <xsl:otherwise>attribute</xsl:otherwise>
    </xsl:choose>
    </p>
</xsl:template>
    
</xsl:transform> 
